==> openGion7.0.0.0_dev.zip: uap/webapps/ge/db/FIREBIRD/sql/install/01_TABLE/GE81S.sql <==
/****************************************************************************/
/* GE81 ( 新着情報ﾃｰﾌﾞﾙ )                                                   */
/*                                                                          */
/* Created : 2017/01/05 15:19:11                                            */
/****************************************************************************/

CREATE TABLE GE81 (
   SYSTEM_ID    VARCHAR (   10 )                    NOT NULL            /*  10 ｼｽﾃﾑID       */
 , SYSCODE      VARCHAR (   20 )        DEFAULT '*' NOT NULL            /*  20 ｼｽﾃﾑｺｰﾄﾞ     */
 , CDDEG        VARCHAR (    1 )                                        /*  30 重要度       */
 , TITLE        VARCHAR (  300 )                                        /*  40 ﾀｲﾄﾙ         */
 , NAIYO        VARCHAR ( 4000 )                                        /*  50 内容         */
 , DYSTRD       VARCHAR (    8 )                    NOT NULL            /*  60 掲載開始日   */
 , DYENDD       VARCHAR (    8 )                    NOT NULL            /*  70 掲載終了日   */
 , BUSHOD       VARCHAR (  100 )                                        /*  80 掲載部署     */
 , MAND         VARCHAR (   50 )                                        /*  90 掲載者       */
 , TEL          VARCHAR (   20 )                                        /* 100 電話番号     */
 , MAILAD       VARCHAR (  100 )                                        /* 110 ﾒｰﾙｱﾄﾞﾚｽ     */
 , FILE1        VARCHAR (  200 )                                        /* 120 ﾌｧｲﾙ1        */
 , FILE2        VARCHAR (  200 )                                        /* 130 ﾌｧｲﾙ2        */
 , FILE3        VARCHAR (  200 )                                        /* 140 ﾌｧｲﾙ3        */
 , FILEPATH     VARCHAR (  200 )                                        /* 150 ﾌｧｲﾙﾊﾟｽ      */
 , TAG          VARCHAR (  200 )                                        /* 160 ﾀｸﾞｷｰﾜｰﾄﾞ    */
 , UNIQ         BIGINT                              NOT NULL            /* 800 ﾕﾆｰｸｷｰ       */
 , FGJ          VARCHAR (    1 )        DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ     */
 , DYSET        VARCHAR (   14 )                                        /* 820 登録日時     */
 , PGSET        VARCHAR (   10 )                                        /* 830 作成PG       */
 , PGPSET       VARCHAR (   10 )                                        /* 840 作成親PG     */
 , USRSET       VARCHAR (   10 )                                        /* 850 作成社員     */
 , DYUPD        VARCHAR (   14 )                                        /* 860 更新日時     */
 , PGUPD        VARCHAR (   10 )                                        /* 870 更新PG       */
 , PGPUPD       VARCHAR (   10 )                                        /* 880 更新親PG     */
 , USRUPD       VARCHAR (   10 )                                        /* 890 更新者       */
);


CREATE SEQUENCE GE81S00 ;


CREATE TRIGGER GE81T00 FOR GE81
  BEFORE INSERT AS 
  BEGIN 
    NEW.UNIQ = GEN_ID( GE81S00,1 );
  END;

==> openGion7.0.3.0_dev.zip: uap/webapps/ge/db/FIREBIRD/sql/install/01_TABLE/GE81S.sql <==
/****************************************************************************/
/* GE81 ( 新着情報ﾃｰﾌﾞﾙ )                                                   */
/*                                                                          */
/* Created : 2018/09/28 16:03:35                                            */
/****************************************************************************/

CREATE TABLE GE81 (
   SYSTEM_ID    VARCHAR (   10 )                    NOT NULL            /*  10 ｼｽﾃﾑID       */
 , SYSCODE      VARCHAR (   20 )        DEFAULT '*' NOT NULL            /*  20 ｼｽﾃﾑｺｰﾄﾞ     */
 , CDDEG        VARCHAR (    1 )                                        /*  30 重要度       */
 , TITLE        VARCHAR (  300 )                                        /*  40 ﾀｲﾄﾙ         */
 , NAIYO        VARCHAR ( 4000 )                                        /*  50 内容         */
 , DYSTRD       VARCHAR (    8 )                    NOT NULL            /*  60 掲載開始日   */
 , DYENDD       VARCHAR (    8 )                    NOT NULL            /*  70 掲載終了日   */
 , BUSHOD       VARCHAR (  100 )                                        /*  80 掲載部署     */
 , MAND         VARCHAR (   50 )                                        /*  90 掲載者       */
 , TEL          VARCHAR (   20 )                                        /* 100 電話番号     */
 , MAILAD       VARCHAR (  100 )                                        /* 110 ﾒｰﾙｱﾄﾞﾚｽ     */
 , FILE1        VARCHAR (  200 )                                        /* 120 ﾌｧｲﾙ1        */
 , FILE2        VARCHAR (  200 )                                        /* 130 ﾌｧｲﾙ2        */
 , FILE3        VARCHAR (  200 )                                        /* 140 ﾌｧｲﾙ3        */
 , FILEPATH     VARCHAR (  200 )                                        /* 150 ﾌｧｲﾙﾊﾟｽ      */
 , TAG          VARCHAR (  200 )                                        /* 160 ﾀｸﾞｷｰﾜｰﾄﾞ    */
 , UNIQ         BIGINT                              NOT NULL            /* 800 ﾕﾆｰｸｷｰ       */
 , FGJ          VARCHAR (    1 )        DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ     */
 , DYSET        VARCHAR (   14 )                                        /* 820 登録日時     */
 , PGSET        VARCHAR (   10 )                                        /* 830 作成PG       */
 , PGPSET       VARCHAR (   10 )                                        /* 840 作成親PG     */
 , USRSET       VARCHAR (   10 )                                        /* 850 作成者       */
 , DYUPD        VARCHAR (   14 )                                        /* 860 更新日時     */
 , PGUPD        VARCHAR (   10 )                                        /* 870 更新PG       */
 , PGPUPD       VARCHAR (   10 )                                        /* 880 更新親PG     */
 , USRUPD       VARCHAR (   10 )                                        /* 890 更新者       */
);


CREATE SEQUENCE GE81S00 ;


CREATE TRIGGER GE81T00 FOR GE81
  BEFORE INSERT AS 
  BEGIN 
    NEW.UNIQ = GEN_ID( GE81S00,1 );
  END;
